import * as _atproto_api_dist_client_types_app_bsky_graph_getFollowers from '@atproto/api/dist/client/types/app/bsky/graph/getFollowers';
import * as _atproto_api_dist_client_types_app_bsky_graph_getFollows from '@atproto/api/dist/client/types/app/bsky/graph/getFollows';
import * as _atproto_api_dist_client_types_app_bsky_actor_defs from '@atproto/api/dist/client/types/app/bsky/actor/defs';
import { BskyAgent, AtpSessionData, AppBskyFeedPost } from '@atproto/api';
import WebSocket from 'ws';

interface JetstreamAspectRatio {
    height: number;
    width: number;
}
interface JetstreamRef {
    $link: string;
}
interface JetstreamSubject {
    cid: string;
    uri: string;
}
interface JetstreamImage {
    $type: string;
    ref: JetstreamRef;
    mimeType: string;
    size: number;
}
interface JetstreamExternal {
    description: string;
    thumb: JetstreamImage;
    title: string;
    uri: string;
}
interface JetstreamFeature {
    $type: string;
    uri: string;
}
interface JetstreamIndex {
    byteEnd: number;
    byteStart: number;
}
interface JetstreamFacet {
    features: JetstreamFeature[];
    index: JetstreamIndex;
}
interface JetstreamImageEmbed {
    alt: string;
    aspectRatio: JetstreamAspectRatio;
    image: JetstreamImage;
}
interface JetstreamReply {
    parent: JetstreamSubject;
    root: JetstreamSubject;
}
type JetstreamCollectionType = 'app.bsky.feed.post' | 'app.bsky.feed.like' | 'app.bsky.feed.repost' | 'app.bsky.graph.follow';
interface JetstreamEvent {
    did: string;
    time_us: number;
    kind: 'commit' | 'account' | 'identity';
    commit?: JetstreamCommit;
    identity?: JetstreamIdentity;
    account?: JetstreamAccount;
}
interface JetstreamCommit {
    rev: string;
    operation: 'create' | 'delete' | 'update';
    collection: JetstreamCollectionType;
    rkey: string;
    record?: JetstreamRecord | NewSkeetRecord;
    cid: string;
}
interface JetstreamEventCommit extends JetstreamEvent {
    commit: JetstreamCommit;
}
interface JetstreamIdentity {
    did: string;
    handle: string;
    seq: number;
    time: string;
}
interface JetstreamEventIdentity extends JetstreamEvent {
    identity: JetstreamIdentity;
}
interface JetstreamAccount {
    active: boolean;
    did: string;
    seq: number;
    time: string;
}
interface JetstreamEventAccount extends JetstreamEvent {
    account: JetstreamAccount;
}
interface JetstreamRecord {
    $type: JetstreamCollectionType;
    createdAt: string;
    subject?: JetstreamSubject | string;
    reply?: JetstreamReply;
}
interface NewSkeetRecord {
    $type: JetstreamCollectionType;
    createdAt: string;
    embed?: {
        $type: string;
        images?: JetstreamImageEmbed[];
        external?: JetstreamExternal;
    };
    facets?: JetstreamFacet[];
    langs?: string[];
    text: string;
    reply?: JetstreamReply;
    subject?: JetstreamSubject | string;
}
type OperationType = 'c' | 'd';
interface JetstreamMessage {
    did: string;
    seq: number;
    opType: OperationType;
    collection: JetstreamCollectionType | string;
    rkey: string;
    cid: string;
}
interface CreateMessage extends JetstreamMessage {
    record: JetstreamRecord;
}
interface DeleteMessage extends JetstreamMessage {
}
interface CreateSkeetMessage extends JetstreamMessage {
    record: CreateSkeetRecord;
}
interface CreateSkeetRecord extends JetstreamRecord {
    embed?: {
        $type: string;
        images?: JetstreamImageEmbed[];
        external?: JetstreamExternal;
    };
    facets?: JetstreamFacet[];
    langs?: string[];
    text?: string;
    reply?: JetstreamReply;
}

declare class HandlerAgent {
    private agentName;
    private handle;
    private password;
    private did;
    private session;
    private agent;
    /**
     *
     */
    constructor(agentName: string, handle: string, password: string, agent?: BskyAgent | undefined);
    /**
     *
     */
    initializeBskyAgent(): BskyAgent;
    /**
     *
     */
    authenticate(): Promise<this | undefined>;
    getSessionLocation(): string;
    saveSessionData(session: AtpSessionData): Promise<void>;
    loadSessionData(): Promise<AtpSessionData | undefined>;
    /**
     * getProfile
     */
    getProfile(did: string): Promise<_atproto_api_dist_client_types_app_bsky_actor_defs.ProfileViewDetailed | undefined>;
    /**
     *
     */
    getFollows(userDID?: string | undefined, cursor?: string | undefined, limit?: number): Promise<_atproto_api_dist_client_types_app_bsky_graph_getFollows.OutputSchema | undefined>;
    /**
     *
     */
    getFollowers(userDID?: string | undefined, cursor?: string | undefined, limit?: number): Promise<_atproto_api_dist_client_types_app_bsky_graph_getFollowers.OutputSchema | undefined>;
    /**
     *
     */
    isFollowing(userDID: string): Promise<boolean>;
    /**
     *
     */
    isFollowedBy(userDID: string): Promise<boolean>;
    /**
     *
     */
    followUser(userDID: string): Promise<boolean>;
    /**
     *
     */
    unfollowUser(userDID: string): Promise<boolean>;
    /**
     *
     * @param details
     */
    post(details: Partial<AppBskyFeedPost.Record> & Omit<AppBskyFeedPost.Record, 'createdAt'>): Promise<{
        uri: string;
        cid: string;
    } | undefined>;
    /**
     *
     */
    createSkeet(newPostDetails: string, skeetReply?: JetstreamReply | undefined): Promise<{
        uri: string;
        cid: string;
    } | undefined>;
    /**
     *
     */
    deleteSkeet(skeetURI: string): Promise<boolean>;
    /**
     *
     */
    likeSkeet(skeetURI: string, skeetCID: string): Promise<boolean>;
    /**
     *
     */
    unlikeSkeet(skeetUri: string): Promise<boolean>;
    /**
     *
     */
    reskeetSkeet(skeetURI: string, skeetCID: string): Promise<boolean>;
    /**
     *
     */
    unreskeetSkeet(skeetUri: string): Promise<boolean>;
    /**
     * Finds a record that is similar to a given skeet URI.
     *
     * @param {string} skeetUri - The skeet URI to find a similar record for.
     * @param {string} [cursor=undefined] - The optional cursor to paginate results.
     * @param {number} [attempt=1] - The number of attempts made to find the record.
     * @returns {Promise<string>} A promise that resolves to the ID of the found record.
     */
    findLikeRecord(skeetUri: string, cursor?: string | undefined, attempt?: number): Promise<string>;
    /**
     * Finds a repost record based on the given parameters.
     * @param {string} skeetUri - The skeet URI to search for.
     * @param {string | undefined} cursor - Optional cursor for pagination.
     * @param {number} attempt - The attempt number for the search.
     * @return {Promise<string>} - A Promise that resolves to the found repost record.
     */
    findRepostRecord(skeetUri: string, cursor?: string | undefined, attempt?: number): Promise<string>;
    /**
     * Finds a specific record in a collection.
     *
     * @param {string} collectionType - The type of collection to search in.
     * @param {string} errorName - The name of the error associated with the record.
     * @param {string} skeetUri - The URI of the record to find.
     * @param {string[]} cursor - The cursor used for pagination (optional).
     * @param {number} attempt - The attempt number (optional).
     *
     * @return {Promise<string>} - A promise that resolves to the URI of the found record.
     */
    findSpecificRecord(collectionType: string, errorName: string, skeetUri: string, cursor?: string | undefined, attempt?: number): Promise<string>;
    /**
     *
     */
    getDIDFromUri(uri: string): string | undefined;
    /**
     *
     */
    postedByAgent(message: JetstreamEventCommit): boolean;
    /**
     *
     */
    generateURIFromCreateMessage(message: JetstreamEventCommit): string;
    /**
     *
     */
    generateReplyFromMessage(event: JetstreamEventCommit): JetstreamReply;
    hasPostReply(message: JetstreamEventCommit): boolean;
    getPostReply(message: JetstreamEventCommit): JetstreamReply | undefined;
    getPostLikeCount(postUri: string): Promise<number>;
    getPostRepostCount(postUri: string): Promise<number>;
    getPostReplyCount(postUri: string): Promise<number>;
    getPostQuoteCount(postUri: string): Promise<number>;
    getPostCount(postUri: string, countType: 'like' | 'repost' | 'reply' | 'quote'): Promise<number>;
    /**
     * Setter for agent.
     * @param agent
     */
    set setAgent(agent: BskyAgent | undefined);
    /**
     * Getter for agent.
     * @return {BskyAgent} The current value of agent.
     */
    get getAgent(): BskyAgent | undefined;
    /**
     * Setter for agentName.
     * @param {string} value - The new value for agentName.
     */
    set setAgentName(value: string);
    /**
     * Getter for agentName.
     * @return {string} The current value of agentName.
     */
    get getAgentName(): string;
    /**
     * Setter for handle.
     * @param {string} value - The new value for handle.
     */
    set setHandle(value: string);
    /**
     * Getter for handle.
     * @return {string} The current value of handle.
     */
    get getHandle(): string;
    /**
     * Setter for password.
     * @param {string} value - The new value for password.
     */
    set setPassword(value: string);
    /**
     * Getter for password.
     * @return {string} The current value of password.
     */
    get getPassword(): string;
    /**
     * Setter for did.
     * @param {string} value - The new value for did.
     */
    set setDid(value: string | undefined);
    /**
     * Getter for did.
     * @return {string} The current value of did.
     */
    get getDid(): string;
    /**
     * Setter for session.
     * @param sess
     */
    set setSession(sess: AtpSessionData | undefined);
    /**
     * Getter for session.
     * @return {any} The current value of session.
     */
    get getSession(): AtpSessionData | boolean;
}

declare abstract class AbstractValidator {
    protected negate: boolean;
    constructor();
    static make(...args: any): AbstractValidator;
    not(): this;
    abstract handle(handlerAgent: HandlerAgent, ...args: any): Promise<boolean>;
    shouldTrigger(handlerAgent: HandlerAgent, ...args: any): Promise<boolean>;
}

declare abstract class AbstractAction {
    constructor();
    static make(...args: any): AbstractAction;
    static getStringOrFunctionReturn(stringOrFunction: string | ((arg0: HandlerAgent, ...args: any) => string), handlerAgent: HandlerAgent, ...args: any): string;
    abstract handle(handlerAgent: HandlerAgent, ...args: any): Promise<any | void>;
}
declare class TestAction extends AbstractAction {
    handle(handlerAgent: HandlerAgent): Promise<any | void>;
}

declare class AbstractHandler {
    protected validators: Array<AbstractValidator>;
    protected actions: Array<AbstractAction | AbstractHandler>;
    handlerAgent: HandlerAgent;
    protected HANDLER_NAME: string;
    constructor(validators: Array<AbstractValidator>, actions: Array<AbstractAction | AbstractHandler>, handlerAgent: HandlerAgent);
    static make(...args: any): AbstractHandler;
    shouldTrigger(...args: any): Promise<boolean>;
    runActions(...args: any): Promise<void>;
    handle(handlerAgent: HandlerAgent | undefined, ...args: any): Promise<void>;
}

declare abstract class AbstractMessageAction extends AbstractAction {
    constructor();
    static make(...args: any): AbstractMessageAction;
    abstract handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<any | void>;
}

declare class MessageHandler extends AbstractHandler {
    protected validators: Array<AbstractValidator>;
    protected actions: Array<AbstractMessageAction | MessageHandler>;
    handlerAgent: HandlerAgent;
    protected HANDLER_NAME: string;
    constructor(validators: Array<AbstractValidator>, actions: Array<AbstractMessageAction | MessageHandler>, handlerAgent: HandlerAgent);
    static getUriFromMessage(handlerAgent: HandlerAgent, message: JetstreamEventCommit): string;
    static getCidFromMessage(handlerAgent: HandlerAgent, message: JetstreamEventCommit): string;
    static generateReplyFromMessage(handlerAgent: HandlerAgent, message: JetstreamEventCommit): JetstreamReply;
    static make(validators: Array<AbstractValidator>, actions: Array<AbstractMessageAction | MessageHandler>, handlerAgent: HandlerAgent): MessageHandler;
}

declare class TestHandler extends AbstractHandler {
    constructor(validators: Array<AbstractValidator>, actions: Array<AbstractAction | MessageHandler>, handlerAgent: HandlerAgent);
    handle(handlerAgent: HandlerAgent | undefined, ...args: any): Promise<void>;
}

declare class TestMessageHandler extends MessageHandler {
    constructor(validators: Array<AbstractValidator>, actions: Array<AbstractMessageAction | MessageHandler>, handlerAgent: HandlerAgent);
    handle(handlerAgent: HandlerAgent | undefined, message: JetstreamEventCommit): Promise<void>;
}

declare class GoodBotHandler extends MessageHandler {
    handlerAgent: HandlerAgent;
    response: string;
    constructor(handlerAgent: HandlerAgent, response?: string);
    static make(handlerAgent: HandlerAgent, response?: string | undefined): GoodBotHandler;
    handle(handlerAgent: HandlerAgent | undefined, message: JetstreamEventCommit): Promise<void>;
}

declare class BadBotHandler extends MessageHandler {
    handlerAgent: HandlerAgent;
    response: string;
    constructor(handlerAgent: HandlerAgent, response?: string);
    static make(handlerAgent: HandlerAgent, response?: string | undefined): BadBotHandler;
    handle(handlerAgent: HandlerAgent | undefined, message: JetstreamEventCommit): Promise<void>;
}

declare class OfflineHandler extends MessageHandler {
    handlerAgent: HandlerAgent;
    private command;
    private response;
    constructor(handlerAgent: HandlerAgent, command: string, response?: string);
    static make(handlerAgent: HandlerAgent, command: string, response?: string | undefined): OfflineHandler;
    handle(handlerAgent: HandlerAgent | undefined, message: JetstreamEventCommit): Promise<void>;
}

declare class TestValidator extends AbstractValidator {
    private shouldPass;
    constructor(shouldPass: boolean);
    static make(shouldPass: boolean): TestValidator;
    handle(handlerAgent: HandlerAgent): Promise<boolean>;
}

/**
 * A validator in which you pass a single function that takes in the post
 * text, and returns a boolean
 */
declare class SimpleFunctionValidator extends AbstractValidator {
    private triggerValidator;
    constructor(triggerValidator: (arg0: HandlerAgent | undefined, ...args: any) => boolean | PromiseLike<boolean>);
    static make(triggerValidator: (arg0: HandlerAgent | undefined, ...args: any) => boolean | PromiseLike<boolean>): SimpleFunctionValidator;
    handle(handlerAgent: HandlerAgent | undefined, ...args: any): Promise<boolean>;
}
/**
 * A validator in which you pass in multiple other validators
 *  and if any of them should trigger, it will return true
 */
declare class OrValidator extends AbstractValidator {
    private validators;
    constructor(validators: Array<AbstractValidator>);
    static make(validators: Array<AbstractValidator>): OrValidator;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<boolean>;
}

declare class IsSpecifiedTimeValidator extends AbstractValidator {
    protected timezones: string[];
    protected matchingTimezones: string[];
    protected times: string[];
    constructor(...times: string[]);
    static make(...times: string[]): IsSpecifiedTimeValidator;
    handle(handlerAgent: HandlerAgent): Promise<boolean>;
}

declare class IsFourTwentyValidator extends AbstractValidator {
    protected timezones: string[];
    protected matchingTimezones: string[];
    constructor();
    static make(): IsFourTwentyValidator;
    handle(handlerAgent: HandlerAgent): Promise<boolean>;
    static getTimezonesWhereItIsFourTwenty(): {
        timezonesAM: string[];
        timezonesPM: string[];
        totalTimezones: number;
    };
}

declare abstract class AbstractMessageValidator extends AbstractValidator {
    constructor();
    static make(...args: any): AbstractMessageValidator;
    getTextFromPost(message: JetstreamEvent): string;
    abstract handle(handlerAgent: HandlerAgent, message: JetstreamEvent): Promise<boolean>;
    shouldTrigger(handlerAgent: HandlerAgent, message: JetstreamEvent): Promise<boolean>;
}

declare class IsGoodBotValidator extends AbstractMessageValidator {
    constructor();
    static make(): IsGoodBotValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class IsBadBotValidator extends AbstractMessageValidator {
    constructor();
    static make(): IsBadBotValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}

declare class ActionTakenByUserValidator extends AbstractMessageValidator {
    private userDid;
    constructor(userDid: string);
    static make(userDid: string): ActionTakenByUserValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}

declare class InputIsCommandValidator extends AbstractMessageValidator {
    private triggerKey;
    private strict;
    constructor(triggerKey: string, strict?: boolean);
    static make(triggerKey: string, strict?: boolean | undefined): InputIsCommandValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class InputStartsWithValidator extends AbstractMessageValidator {
    private triggerKey;
    private strict;
    constructor(triggerKey: string, strict?: boolean);
    static make(triggerKey: string, strict?: boolean | undefined): InputStartsWithValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class InputContainsValidator extends AbstractMessageValidator {
    private triggerKey;
    private strict;
    constructor(triggerKey: string, strict?: boolean);
    static make(triggerKey: string, strict?: boolean | undefined): InputContainsValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class InputEqualsValidator extends AbstractMessageValidator {
    private triggerKey;
    constructor(triggerKey: string);
    static make(triggerKey: string): InputEqualsValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}

declare class PostedByUserValidator extends AbstractMessageValidator {
    private userDid;
    constructor(userDid: string);
    static make(userDid: string): PostedByUserValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class ReplyingToBotValidator extends AbstractMessageValidator {
    constructor();
    static make(): ReplyingToBotValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class IsReplyValidator extends AbstractMessageValidator {
    constructor();
    static make(): IsReplyValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class IsNewPost extends AbstractMessageValidator {
    constructor();
    static make(): IsNewPost;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}

declare class NewFollowerForUserValidator extends AbstractMessageValidator {
    private userDid;
    constructor(userDid: string | undefined);
    static make(userDid?: string | undefined): NewFollowerForUserValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class NewFollowFromUserValidator extends AbstractMessageValidator {
    private userDid;
    constructor(userDid: string | undefined);
    static make(userDid?: string | undefined): NewFollowFromUserValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
/**
 * Deprecated name. NewFollowFromUserValidator is named better to go with the other Follow Validator
 */
declare class UserFollowedValidator extends NewFollowFromUserValidator {
}

declare class RepostByUser extends AbstractMessageValidator {
    private userDid;
    private postUri;
    constructor(userDid: string | undefined, postUri: string | undefined);
    static make(userDid?: string | undefined, postUri?: string | undefined): RepostByUser;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class RepostOfUser extends AbstractMessageValidator {
    private userDid;
    private postUri;
    constructor(userDid: string | undefined, postUri: string | undefined);
    static make(userDid?: string | undefined, postUri?: string | undefined): RepostOfUser;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class RepostOfPost extends AbstractMessageValidator {
    private postUri;
    constructor(postUri: string);
    static make(postUri: string): RepostOfPost;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}

declare class LikeByUser extends AbstractMessageValidator {
    private userDid;
    private postUri;
    constructor(userDid: string | undefined, postUri: string | undefined);
    static make(userDid?: string | undefined, postUri?: string | undefined): LikeByUser;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class LikeOfUser extends AbstractMessageValidator {
    private userDid;
    private postUri;
    constructor(userDid: string | undefined, postUri: string | undefined);
    static make(userDid?: string | undefined, postUri?: string | undefined): LikeOfUser;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}
declare class LikeOfPost extends AbstractMessageValidator {
    private postUri;
    constructor(postUri: string);
    static make(postUri: string): LikeOfPost;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}

type ComparisonType = 'equal' | 'greaterThan' | 'lessThan' | 'between';
declare class PostLikesValidator extends AbstractMessageValidator {
    private postUri;
    private comparisonType;
    private likeCount?;
    private likeCountMin?;
    private likeCountMax?;
    constructor(postUri: string, comparisonType: ComparisonType, likeCount?: number | undefined, // Optional for 'between'
    likeCountMin?: number | undefined, // Required for 'between'
    likeCountMax?: number | undefined);
    static make(postUri: string, comparisonType: ComparisonType, likeCount?: number, likeCountMin?: number, likeCountMax?: number): PostLikesValidator;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<boolean>;
}

declare class FunctionAction extends AbstractAction {
    private actionFunction;
    constructor(actionFunction: (arg0: HandlerAgent, ...args: any) => any);
    static make(actionFunction: (arg0: HandlerAgent, ...args: any) => any): FunctionAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}

declare class LogInputTextAction extends AbstractAction {
    private logText;
    constructor(logText: string | ((arg0: HandlerAgent, ...args: any) => string));
    static make(logText: string | ((arg0: HandlerAgent, ...args: any) => string)): LogInputTextAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}
declare class DebugLogAction extends AbstractAction {
    private action;
    private message;
    private level;
    constructor(action: string | ((arg0: HandlerAgent, ...args: any) => string), message: string | ((arg0: HandlerAgent, ...args: any) => string), level?: string);
    static make(action: string | ((arg0: HandlerAgent, ...args: any) => string), message: string | ((arg0: HandlerAgent, ...args: any) => string), level?: string): DebugLogAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}

declare class CreateSkeetAction extends AbstractAction {
    protected skeetText: string | ((arg0: HandlerAgent, ...args: any) => string);
    protected skeetReply: JetstreamReply | ((arg0: HandlerAgent, ...args: any) => JetstreamReply) | undefined;
    constructor(skeetText: string | ((arg0: HandlerAgent, ...args: any) => string), skeetReply?: JetstreamReply | ((arg0: HandlerAgent, ...args: any) => JetstreamReply) | undefined);
    static make(skeetText: string | ((arg0: HandlerAgent, ...args: any) => string), skeetReply?: JetstreamReply | ((arg0: HandlerAgent, ...args: any) => JetstreamReply) | undefined): CreateSkeetAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}
declare class DeleteSkeetAction extends AbstractAction {
    protected skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string);
    constructor(skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string));
    static make(skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string)): DeleteSkeetAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}

declare class CreateLikeAction extends AbstractAction {
    protected skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string);
    protected skeetCid: string | ((arg0: HandlerAgent, ...args: any) => string);
    constructor(skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string), skeetCid: string | ((arg0: HandlerAgent, ...args: any) => string));
    static make(skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string), skeetCid: string | ((arg0: HandlerAgent, ...args: any) => string)): CreateLikeAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}
declare class DeleteLikeAction extends AbstractAction {
    protected skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string);
    constructor(skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string));
    static make(skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string)): DeleteLikeAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}

declare class CreateReskeetAction extends AbstractAction {
    protected skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string);
    protected skeetCid: string | ((arg0: HandlerAgent, ...args: any) => string);
    constructor(skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string), skeetCid: string | ((arg0: HandlerAgent, ...args: any) => string));
    static make(skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string), skeetCid: string | ((arg0: HandlerAgent, ...args: any) => string)): CreateReskeetAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}
declare class DeleteReskeetAction extends AbstractAction {
    protected skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string);
    constructor(skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string));
    static make(skeetUri: string | ((arg0: HandlerAgent, ...args: any) => string)): DeleteReskeetAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}

declare class CreateFollowAction extends AbstractAction {
    protected userDid: string | ((arg0: HandlerAgent, ...args: any) => string);
    constructor(userDid: string | ((arg0: HandlerAgent, ...args: any) => string));
    static make(userDid: string | ((arg0: HandlerAgent, ...args: any) => string)): CreateFollowAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}
declare class DeleteFollowAction extends AbstractAction {
    protected userDid: string | ((arg0: HandlerAgent, ...args: any) => string);
    constructor(userDid: string | ((arg0: HandlerAgent, ...args: any) => string));
    static make(userDid: string | ((arg0: HandlerAgent, ...args: any) => string)): DeleteFollowAction;
    handle(handlerAgent: HandlerAgent, ...args: any): Promise<any>;
}

declare class TestMessageAction extends AbstractMessageAction {
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<any | void>;
}

declare class LogMessageAction extends AbstractMessageAction {
    static make(): LogMessageAction;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<any>;
}

declare class CreateSkeetMessageAction extends AbstractMessageAction {
    private skeetText;
    constructor(skeetText: string);
    static make(skeetText: string): CreateSkeetMessageAction;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<any>;
}
declare class CreateSkeetWithGeneratedTextAction extends AbstractMessageAction {
    private textGenerator;
    constructor(textGenerator: (arg0: HandlerAgent, arg1: JetstreamEventCommit) => string);
    static make(textGenerator: (arg0: HandlerAgent, arg1: JetstreamEventCommit) => string): CreateSkeetWithGeneratedTextAction;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<any>;
}
declare class ReplyToSkeetAction extends AbstractMessageAction {
    private replyText;
    constructor(replyText: string);
    static make(replyText: string): ReplyToSkeetAction;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<any>;
}
declare class ReplyToSkeetWithGeneratedTextAction extends AbstractMessageAction {
    private textGenerator;
    constructor(textGenerator: (arg0: HandlerAgent, arg1: JetstreamEventCommit) => string);
    static make(textGenerator: (arg0: HandlerAgent, arg1: JetstreamEventCommit) => string): ReplyToSkeetWithGeneratedTextAction;
    handle(handlerAgent: HandlerAgent, message: JetstreamEventCommit): Promise<any>;
}

interface CreateAndDeleteHandlersInterface {
    c?: MessageHandler[];
    d?: MessageHandler[];
}
interface JetstreamSubscriptionHandlers {
    post?: CreateAndDeleteHandlersInterface;
    like?: CreateAndDeleteHandlersInterface;
    repost?: CreateAndDeleteHandlersInterface;
    follow?: CreateAndDeleteHandlersInterface;
}
declare class JetstreamSubscription extends AbstractSubscription {
    protected handlerControllers: JetstreamSubscriptionHandlers;
    protected wsURL: string;
    wsClient: WebSocket;
    lastMessageTime: number | undefined;
    restart: boolean;
    restartDelay: number;
    /**
     * Creates a new instance of the Firehose Subscription.
     *
     * @param {JetstreamSubscriptionHandlers} handlerControllers - An array of handler controllers.
     * @param {string} wsURL - The WebSocket URL to connect to. Defaults to `wss://bsky.network`.
     */
    constructor(handlerControllers: JetstreamSubscriptionHandlers, wsURL?: string);
    set setWsURL(url: string);
    generateWsURL(): void;
    /**
     *
     */
    createSubscription(): this;
    handleOpen(): void;
    handleError(err: Error): void;
    stopSubscription(restart?: boolean): this;
    handleCreate(createEvent: JetstreamEventCommit): void;
    handleDelete(deleteEvent: JetstreamEventCommit): void;
}

interface IntervalSchemaInterface {
    intervalSeconds: number;
    handlers: AbstractHandler[];
}
type IntervalSubscriptionHandlers = IntervalSchemaInterface[];
declare class IntervalSubscription extends AbstractSubscription {
    protected intervalHandlers: IntervalSubscriptionHandlers;
    protected _intervals: any[];
    constructor(intervalHandlers: IntervalSubscriptionHandlers);
    get intervals(): any[];
    createSubscription(): IntervalSubscription;
    stopSubscription(): IntervalSubscription;
}

declare abstract class AbstractSubscription {
    protected handlers: JetstreamSubscriptionHandlers | IntervalSubscriptionHandlers | AbstractHandler[];
    constructor(handlers: JetstreamSubscriptionHandlers | IntervalSubscriptionHandlers | AbstractHandler[]);
    abstract createSubscription(): AbstractSubscription;
    abstract stopSubscription(): AbstractSubscription;
    restartSubscription(): AbstractSubscription;
}

declare abstract class AbstractTypeFactory {
    constructor();
    static factory(): void;
    static make(): void;
    create(): void;
}
declare class TestFactory extends AbstractTypeFactory {
}

declare class JetstreamEventFactory extends AbstractTypeFactory {
    eventObject: JetstreamEvent;
    constructor();
    static factory(): JetstreamEventFactory;
    static make(): JetstreamEvent;
    create(): JetstreamEvent;
    fromDid(did: string): this;
    commit(commit?: JetstreamCommit | undefined): JetstreamEventFactory;
}
declare class JetstreamCommitFactory extends AbstractTypeFactory {
    eventObject: JetstreamCommit;
    constructor();
    static factory(): JetstreamCommitFactory;
    static make(): JetstreamCommit;
    create(): JetstreamCommit;
    rkey(rkey: string): this;
    record(record: JetstreamRecord | NewSkeetRecord): this;
    operation(operation: 'create' | 'update' | 'delete'): this;
    collection(collection: JetstreamCollectionType): this;
    text(text: string): this;
}
declare class JetstreamIdentityFactory extends AbstractTypeFactory {
    eventObject: JetstreamIdentity;
    constructor();
    static factory(): JetstreamIdentityFactory;
    static make(): JetstreamIdentity;
    create(): JetstreamIdentity;
    handle(handle: string): JetstreamIdentityFactory;
    sequence(seq: number): JetstreamIdentityFactory;
}
declare class JetstreamAccountFactory extends AbstractTypeFactory {
    eventObject: JetstreamAccount;
    constructor();
    static factory(): JetstreamAccountFactory;
    static make(): JetstreamAccount;
    create(): JetstreamAccount;
    deactivate(): JetstreamAccountFactory;
    sequence(seq: number): JetstreamAccountFactory;
}

declare class JetstreamRecordFactory extends AbstractTypeFactory {
    record: JetstreamRecord;
    constructor();
    static factory(): JetstreamRecordFactory;
    static make(): JetstreamRecord;
    create(): JetstreamRecord;
    type(inputType: JetstreamCollectionType): this;
    isLike(): this;
    isRepost(): this;
    isFollow(followedDid?: string | undefined): this;
    subject(inputSubject: JetstreamSubject | string): this;
}
declare class NewSkeetRecordFactory extends AbstractTypeFactory {
    record: NewSkeetRecord;
    constructor();
    static factory(): NewSkeetRecordFactory;
    static make(): NewSkeetRecord;
    create(): NewSkeetRecord;
    reply(reply?: JetstreamReply | undefined): this;
    text(text: string): this;
}
/**
 * Represents a factory class for creating a skeet record object.
 * @extends AbstractTypeFactory
 */
declare class CreateSkeetRecordFactory extends AbstractTypeFactory {
    skeetRecordObject: CreateSkeetRecord;
    /**
     * Create a new instance of the CreateSkeetRecordFactory.
     *
     * @constructor
     */
    constructor();
    /**
     * Factory method for creating an instance of CreateSkeetRecordFactory.
     *
     * @returns {CreateSkeetRecordFactory} The new instance of CreateSkeetRecordFactory.
     */
    static factory(): CreateSkeetRecordFactory;
    static make(): CreateSkeetRecord;
    /**
     * Creates a new {CreateSkeetRecord} object from the factoru data.
     *
     * @returns {CreateSkeetRecord} The newly created {CreateSkeetRecord} object.
     */
    create(): CreateSkeetRecord;
    /**
     * Set the text for the Skeet JetstreamRecord object.
     *
     * @param {string} skeetText - The text to be set for the Skeet JetstreamRecord.
     * @return {CreateSkeetRecordFactory} - The update instance of CreateSkeetRecordFactory.
     */
    text(skeetText: string): CreateSkeetRecordFactory;
    /**
     * Sets the reply value for a SkeetRecordFactory object.
     *
     * @param {JetstreamReply} skeetReply - The reply value to be set for the SkeetRecordFactory object.
     * @return {CreateSkeetRecordFactory} - The update instance of CreateSkeetRecordFactory.
     */
    reply(skeetReply: JetstreamReply): CreateSkeetRecordFactory;
}
declare class JetstreamSubjectFactory extends AbstractTypeFactory {
    subject: JetstreamSubject;
    constructor();
    static factory(): JetstreamSubjectFactory;
    static make(): JetstreamSubject;
    create(): JetstreamSubject;
    cid(inputCid: string): this;
    uri(inputUri: string): this;
}
/**
 * A factory class for creating JetstreamReply objects.
 * @extends AbstractTypeFactory
 */
declare class ReplyFactory extends AbstractTypeFactory {
    reply: JetstreamReply;
    constructor();
    static factory(): ReplyFactory;
    static make(): JetstreamReply;
    create(): JetstreamReply;
    /**
     * Sets the root subject for the reply.
     *
     * @param {JetstreamSubject} replyRoot - The root subject for the reply.
     * @return {ReplyFactory} - The updated instance of the ReplyFactory.
     */
    root(replyRoot: JetstreamSubject): ReplyFactory;
    /**
     * Sets the parent reply for the given subject.
     *
     * @param {JetstreamSubject} replyParent - The parent reply to be set.
     * @return {ReplyFactory} - The updated instance of the ReplyFactory.
     */
    parent(replyParent: JetstreamSubject): ReplyFactory;
    /**
     * Sets the parent URI for replying to a message.
     *
     * @param {string} did - The decentralized identifier (DID) of the user.
     * @return {ReplyFactory} - The updated instance of the ReplyFactory.
     */
    replyTo(did: string): ReplyFactory;
}

declare function flattenTextUpdated(triggerKey: string, input: string): string;
declare function removePunctuation(input: string): string;
declare function removeNumbers(input: string): string;
declare function removeSpaces(input: string): string;
declare function containsNumbers(str: string): boolean;
declare function containsPunctuation(str: string): boolean;
declare function containsSpaces(str: string): boolean;
declare function trimCommandInput(input: string, command: string): string | boolean;
declare function isGoodBotResponse(input: string): boolean;
declare function isBadBotResponse(input: string): boolean;

declare function debugLog(action: string, message: string, level?: string): void;

declare function getHumanReadableDateTimeStamp(datetime: string, timezone?: string): string;
declare function nowDateTime(): string;
declare function getTimezonesWhereItIsAGivenTime(timeToCheck: string): string[];
declare function isTimeInHHMMFormat(time: string): boolean;

declare class DebugLog {
    static debug(action: string, message: string): void;
    static info(action: string, message: string): void;
    static warn(action: string, message: string): void;
    static error(action: string, message: string): void;
    static log(action: string, message: string, level?: string): void;
}

export { AbstractAction, AbstractHandler, AbstractMessageAction, AbstractSubscription, AbstractTypeFactory, AbstractValidator, ActionTakenByUserValidator, BadBotHandler, type CreateAndDeleteHandlersInterface, CreateFollowAction, CreateLikeAction, type CreateMessage, CreateReskeetAction, CreateSkeetAction, type CreateSkeetMessage, CreateSkeetMessageAction, type CreateSkeetRecord, CreateSkeetRecordFactory, CreateSkeetWithGeneratedTextAction, DebugLog, DebugLogAction, DeleteFollowAction, DeleteLikeAction, type DeleteMessage, DeleteReskeetAction, DeleteSkeetAction, FunctionAction, GoodBotHandler, HandlerAgent, InputContainsValidator, InputEqualsValidator, InputIsCommandValidator, InputStartsWithValidator, type IntervalSchemaInterface, IntervalSubscription, type IntervalSubscriptionHandlers, IsBadBotValidator, IsFourTwentyValidator, IsGoodBotValidator, IsNewPost, IsReplyValidator, IsSpecifiedTimeValidator, type JetstreamAccount, JetstreamAccountFactory, type JetstreamAspectRatio, type JetstreamCollectionType, type JetstreamCommit, JetstreamCommitFactory, type JetstreamEvent, type JetstreamEventAccount, type JetstreamEventCommit, JetstreamEventFactory, type JetstreamEventIdentity, type JetstreamExternal, type JetstreamFacet, type JetstreamFeature, type JetstreamIdentity, JetstreamIdentityFactory, type JetstreamImage, type JetstreamImageEmbed, type JetstreamIndex, type JetstreamMessage, type JetstreamRecord, JetstreamRecordFactory, type JetstreamRef, type JetstreamReply, type JetstreamSubject, JetstreamSubjectFactory, JetstreamSubscription, type JetstreamSubscriptionHandlers, LikeByUser, LikeOfPost, LikeOfUser, LogInputTextAction, LogMessageAction, MessageHandler, NewFollowFromUserValidator, NewFollowerForUserValidator, type NewSkeetRecord, NewSkeetRecordFactory, OfflineHandler, type OperationType, OrValidator, PostLikesValidator, PostedByUserValidator, ReplyFactory, ReplyToSkeetAction, ReplyToSkeetWithGeneratedTextAction, ReplyingToBotValidator, RepostByUser, RepostOfPost, RepostOfUser, SimpleFunctionValidator, TestAction, TestFactory, TestHandler, TestMessageAction, TestMessageHandler, TestValidator, UserFollowedValidator, containsNumbers, containsPunctuation, containsSpaces, debugLog, flattenTextUpdated, getHumanReadableDateTimeStamp, getTimezonesWhereItIsAGivenTime, isBadBotResponse, isGoodBotResponse, isTimeInHHMMFormat, nowDateTime, removeNumbers, removePunctuation, removeSpaces, trimCommandInput };
